@@ -50,7 +50,7 @@
 #if defined(WIN32) && !defined(__CYGWIN32__)
 #include <io.h>
 #define	_IOLEN64	(unsigned)
-#define	_IORET64	(ssize_t)
+#define	_IORET64	(int)
 #define TIMEOUT_INF ~((timeout_t) 0)
 typedef int socklen_t;
 #else
