@@ -808,7 +808,12 @@ SharedFile::Error SharedFile::fetch(caddr_t address, ccxx_size_t len, off_t pos)
 
 #else
 	lseek(fd, fcb.pos, SEEK_SET);
-	lockf(fd, F_LOCK, fcb.len);
+	if(lockf(fd, F_LOCK, fcb.len))
+	{
+		leaveMutex();
+		return errLockFailure;
+	}
+		
 	int io = ::read(fd, fcb.address, fcb.len);
 	leaveMutex();
 
@@ -842,7 +847,11 @@ SharedFile::Error SharedFile::clear(ccxx_size_t len, off_t pos)
 		fcb.pos = pos;
 
 	lseek(fd, fcb.pos, SEEK_SET);
-	lockf(fd, F_ULOCK, fcb.len);
+	if(lockf(fd, F_ULOCK, fcb.len))
+	{
+		leaveMutex();
+		return errLockFailure;
+	}
 	leaveMutex();
 	return errSuccess;
 }
@@ -895,7 +904,11 @@ SharedFile::Error SharedFile::update(caddr_t address, ccxx_size_t len, off_t pos
 #else
 	lseek(fd, fcb.pos, SEEK_SET);
 	int io = ::write(fd, fcb.address, fcb.len);
-	lockf(fd, F_ULOCK, fcb.len);
+	if(lockf(fd, F_ULOCK, fcb.len))
+	{
+		leaveMutex();
+		return errLockFailure;
+	}
 	leaveMutex();
 
 	if((size_t) io == fcb.len)
@@ -961,11 +974,19 @@ SharedFile::Error SharedFile::append(caddr_t address, ccxx_size_t len)
 
 #else
 	fcb.pos = lseek(fd, 0l, SEEK_END);
-	lockf(fd, F_LOCK, -1);
+	if(lockf(fd, F_LOCK, -1))
+	{
+		leaveMutex();
+		return errLockFailure;
+	}
 	fcb.pos = lseek(fd, 0l, SEEK_END);
 	int io = ::write(fd, fcb.address, fcb.len);
 	lseek(fd, fcb.pos, SEEK_SET);
-	lockf(fd, F_ULOCK, -1);
+	if(lockf(fd, F_ULOCK, -1))
+	{
+		leaveMutex();
+		return errLockFailure;
+	}
 	leaveMutex();
 
 	if((size_t) io == fcb.len)
