@@ -73,7 +73,7 @@ IPV6Address::IPV6Address(const IPV6Validator *_validator)
 }
 
 IPV6Address::IPV6Address(const char *address, const IPV6Validator *_validator) : 
-	validator(_validator), addr_count(0), ipaddr(NULL), hostname(NULL)
+	validator(_validator), ipaddr(NULL), addr_count(0), hostname(NULL)
 {
 	if ( this->validator )
 		this->validator = validator;
