@@ -184,6 +184,63 @@ const char *Keydata::getFirst(const char *sym)
 	return val->val;
 }
 
+const char *Keydata::getString(const char *sym, const char *def)
+{
+	const char *cp = getLast(sym);
+
+	if(!cp)
+		return def;
+
+	return cp;
+}
+
+long Keydata::getLong(const char *sym, long def)
+{
+	const char *cp = getLast(sym);
+
+	if(!cp)
+		return def;
+
+	return atol(cp);
+}
+
+double Keydata::getDouble(const char *sym, double def)
+{
+	const char *cp = getLast(sym);
+
+	if(!cp)
+		return def;
+
+	return atof(cp);
+}
+
+bool Keydata::getBool(const char *sym)
+{
+	const char *cp = getLast(sym);
+
+	if(!cp)
+		return false;
+
+	switch(*cp)
+	{
+	case 'y':
+	case 'Y':
+	case 't':
+	case 'T':
+		return true;
+	default:
+		return false;
+	}
+}
+
+bool Keydata::isKey(const char *sym)
+{
+	if(getLast(sym))
+		return true;
+
+	return false;
+}
+
 const char *Keydata::getLast(const char *sym)
 {
 	Keysym *key = getSymbol(sym, false);
