@@ -84,6 +84,8 @@ namespace ost {
 static char *_pUser = NULL;
 static char *_pHome = NULL;
 
+bool Process::rtflag = false;
+
 #ifdef	WIN32
 
 static SYSTEM_INFO sysinfo;
@@ -558,7 +560,10 @@ void Process::setScheduler(const char *pol)
 #endif
 #ifdef	SCHED_FIFO
 		if(!stricmp(pol, "fifo"))
+		{
+			rtflag = true;
 			policy = SCHED_FIFO;
+		}
 #endif
 #ifdef	SCHED_TS
 		if(!stricmp(pol, "ts"))
