@@ -1600,7 +1600,26 @@ Thread(pri, stack), Mutex(id)
 	first = last = NULL;
 	count = 0;
 	FD_ZERO(&connect);
-	::pipe(iosync);
+	if(::pipe(iosync))
+	{
+#ifdef  CCXX_EXCEPTIONS
+                switch(Thread::getException())
+                {
+                case throwObject:
+                        throw(this);
+                        return;
+#ifdef  COMMON_STD_EXCEPTION
+                case throwException:
+                        throw(ThrException("no service pipe"));
+                        return;
+#endif
+                default:
+                        return;
+                }
+#else
+                return;
+#endif
+	}
 	hiwater = iosync[0] + 1;
 	FD_SET(iosync[0], &connect);
 
@@ -1684,7 +1703,27 @@ void SerialService::detach(SerialPort *port)
 
 void SerialService::update(unsigned char flag)
 {
-	::write(iosync[1], (char *)&flag, 1);
+	if(::write(iosync[1], (char *)&flag, 1) < 1)
+        {
+
+#ifdef  CCXX_EXCEPTIONS
+                switch(Thread::getException())
+                {
+                case throwObject:
+                        throw(this);
+                        return;
+#ifdef  COMMON_STD_EXCEPTION
+                case throwException:
+                        throw(ThrException("update failed"));
+                        return;
+#endif
+                default:
+                        return;
+                }
+#else
+                return;
+#endif
+	}
 }
 
 		
