@@ -163,7 +163,7 @@ ssize_t SimpleTCPStream::read(char *bytes, size_t length, timeout_t timeout)
 		}
 		
 		// Attempt to read data.
-		rlen = _IORET64 ::recv(so, (char *) currentpos, _IOLEN64 length-totalrecv, 0);
+		rlen = _IORET64 ::recv(so, (char *) currentpos, _IOLEN64 (length-totalrecv), 0);
 		if (rlen == 0 || rlen == -1) {
 			break;
 		}
@@ -233,7 +233,7 @@ ssize_t SimpleTCPStream::peek(char *bytes, size_t length, timeout_t timeout)
 		}
 
 		// Attempt to read data.
-		rlen = _IORET64 ::recv(so, (char *) currentpos, _IOLEN64 length-totalrecv, MSG_PEEK);
+		rlen = _IORET64 ::recv(so, (char *) currentpos, _IOLEN64 (length-totalrecv), MSG_PEEK);
 		if (rlen == 0 || rlen == -1) {
 			break;
 		}
