@@ -3330,7 +3330,7 @@ void TCPSession::initial(void)
 		exit();
 }
 
-CCXX_EXPORT(ostream&) operator<<(ostream &os, const IPV4Address &ia)
+ostream& operator<<(ostream &os, const IPV4Address &ia)
 {
 	os << inet_ntoa(getaddress(ia));
 	return os;
