@@ -782,6 +782,9 @@ void XMLStream::endDocument(void)
 {
 }
 
+XMLStream::~XMLStream()
+{}
+
 #ifdef	CCXX_NAMESPACES
 }
 #endif
